@@ -24,7 +24,7 @@ use Time::HiRes qw/time/;
 Readonly my $HTTP_OK => 200;
 Readonly my $HTTP_FILE_NOT_FOUND => 404;
 
-our $VERSION = '1.07';
+our $VERSION = '1.08';
 
 # TODO: Timeout, fallback
 # TODO: Expected result content (json etc)
@@ -41,15 +41,18 @@ has 'request_timeout'    => sub { $ENV{MOJO_REQUEST_TIMEOUT}    // 0   };
 has 'local_dir'          => sub { $ENV{MUAC_LOCAL_DIR}          // q{}   };
 has 'always_return_file' => sub { $ENV{MUAC_ALWAYS_RETURN_FILE} // undef };
 
-has 'cache_agent'        => sub { $ENV{MUAC_NOCACHE} ? () : CHI->new(
-        driver             => $ENV{MUAC_CACHE_DRIVER}             || 'File',
-        root_dir           => $ENV{MUAC_CACHE_ROOT_DIR}           || '/tmp/mojo-useragent-cached',
-        serializer         => $ENV{MUAC_CACHE_SERIALIZER}         || 'Storable',
-        namespace          => $ENV{MUAC_CACHE_NAMESPACE}          || 'MUAC_Client',
-        expires_in         => $ENV{MUAC_CACHE_EXPIRES_IN}         // '1 minute',
-        expires_on_backend => $ENV{MUAC_CACHE_EXPIRES_ON_BACKEND} // 1,
-)};
-
+has 'cache_agent'        => sub {
+  $ENV{MUAC_NOCACHE} ? () : CHI->new(
+    driver             => $ENV{MUAC_CACHE_DRIVER}             || 'File',
+    root_dir           => $ENV{MUAC_CACHE_ROOT_DIR}           || '/tmp/mojo-useragent-cached',
+    serializer         => $ENV{MUAC_CACHE_SERIALIZER}         || 'Storable',
+    namespace          => $ENV{MUAC_CACHE_NAMESPACE}          || 'MUAC_Client',
+    expires_in         => $ENV{MUAC_CACHE_EXPIRES_IN}         // '1 minute',
+    expires_on_backend => $ENV{MUAC_CACHE_EXPIRES_ON_BACKEND} // 1,
+    %{ shift->cache_opts || {} },
+  )
+};
+has 'cache_opts'                 => sub { {} };
 has 'cache_url_opts'             => sub { {} };
 has 'logger'                     => sub { Mojo::Log->new() };
 has 'access_log'                 => sub { $ENV{MUAC_ACCESS_LOG} || '' };
@@ -527,6 +530,13 @@ Tells L<Mojo::UserAgent::Cached> which cache_agent to use. It needs to be CHI-co
 
 You may also set the C<MUAC_NOCACHE> environment variable to avoid caching at all.
 
+=head2 cache_opts
+
+  my $cache_opts = $ua->cache_opts;
+  $ua->cache_opts({ expires_in => '5 minutes' });
+
+Allows passing in cache options that will be appended to existing options in default cache agent creation.
+
 =head2 cache_url_opts
 
   my $urls_href = $ua->cache_url_opts;
